pub enum MeshMorphBindGroupKey {
NoMorphTargets,
Uniform(AssetId<Mesh>),
Storage(MeshSlabId),
}Expand description
Data related to morph targets that we need in order to look up the bind group for a mesh.
Variants
NoMorphTargets
The mesh has no morph targets.
Uniform(AssetId<Mesh>)
The mesh has morph targets, and the current platform doesn’t support storage buffers.
In this case, there’s a single bind group per mesh.
Storage(MeshSlabId)
The mesh has morph targets, and the current platform does support storage buffers.
In this case, there’s a bind group per morph displacement slab (managed by the mesh allocator).