pub struct ShadowBatchSetKey {
pub pipeline: CachedRenderPipelineId,
pub draw_function: DrawFunctionId,
pub material_bind_group_index: Option<u32>,
pub vertex_slab: SlabId,
pub index_slab: Option<SlabId>,
}Expand description
Information that must be identical in order to place opaque meshes in the same batch set.
A batch set is a set of batches that can be multi-drawn together, if multi-draw is in use.
Fields
pipeline: CachedRenderPipelineIdThe identifier of the render pipeline.
draw_function: DrawFunctionIdThe function used to draw.
material_bind_group_index: Option<u32>The ID of a bind group specific to the material.
In the case of PBR, this is the MaterialBindGroupIndex.
vertex_slab: SlabIdThe ID of the slab of GPU memory that contains vertex data.
For non-mesh items, you can fill this with 0 if your items can be multi-drawn, or with a unique value if they can’t.
index_slab: Option<SlabId>The ID of the slab of GPU memory that contains index data, if present.
For non-mesh items, you can safely fill this with None.